@@ -33,6 +33,9 @@ class EnoughApp(App):
         root_logger = logging.getLogger('enough')
         root_logger.setLevel(level)
 
+    def initialize_app(self, argv):
+        os.environ['ENOUGH_DOMAIN'] = self.options.domain
+
     def build_option_parser(self, description, version, argparse_kwargs=None):
         parser = super().build_option_parser(description, version, argparse_kwargs)
         parser.add_argument('--domain', default='enough.community', help='Enough domain name')
